package name.panitz.eliza;
import static name.panitz.eliza.ListUtil.*;
import static name.panitz.eliza.LiImpl.cons;
import static name.panitz.eliza.Map.map;

/**
  This class contains key/value pairs of how to react
  on certain messages. The data has been taken from the 
  original Eliza implementation in Gofer done by Mark P. Jones.
**/
public class Data {

  public Data(){init();}

  /**
        respMsgs associates possible answers patterns to certain 
        keywords in the qustion.

        This is a list of pairs. The first element of the pair is a String. 
        The second a list of possible answers for questions 
        containing the first element.
  **/
  public  Map<Li<String>,Li<String>> respMsgs;   

  public  Map<String,String> CONJUGATES ;
    /**
       A list of reactions, when the same question has been repeated.
     **/
  public Li<String> repeatMsgs; 

  private Li<String> nokeyMsgs;
  private Li<String> canYou;
  private Li<String> canI;
  private Li<String>  youAre;
  private Li<String>  iDont;
  private Li<String>  iFeel	;   
  private Li<String>  iHave;
  private Li<String>  whyDont ; 
  private Li<String>  whyCant;
  private Li<String>  areYou;
  private Li<String>  iCant;
  private Li<String>  iAm	 ;   
  private Li<String>  you	;     
  private Li<String>  yes;
  private Li<String>  no;
  private Li<String>  computer;
  private Li<String>  problem;
  private Li<String>  iWant;
  private Li<String>  question;
  private Li<String>  name;
  private Li<String>  because;
  private Li<String>  sorry	;
  private Li<String>  dream;
  private Li<String>  hello;
  private Li<String>  maybe;
  private Li<String>  your;
  private Li<String>  always;
  private Li<String>  think;
  private Li<String>  alike;
  private Li<String>  friend;

  private void init(){
   CONJUGATES = 
     map("me","you",
     map("are","am",
     map("were","was",
     map("you","I",
     map("your","my",
     map("I've","you've",
     map("I'm","you're",
     map("am","are",
     map("was","were",
     map("I","you",
     map("my","your",
     map("you've","I've",
     map("you're","I'm",
     new Map<String,String>()))))))))))))) ;

  repeatMsgs
    = cons( "Why did you repeat yourself?",
      cons( "Do you expect a different answer by repeating yourself?",
      cons( "Come, come, elucidate your thoughts.",
      cons( "Please don't repeat yourself!" ,
      new LiImpl<String>()))));

  nokeyMsgs
    = new LiImpl<String>( "I'm not sure I understand you fully.",
      cons( "What does that suggest to you?",
      cons( "I see.",
      cons( "Can you elaborate on that?",
      cons( "Say, do you have any psychological problems?" ,
      new LiImpl<String>())))));


   canYou
     = cons( "?Don't you believe that I can",
       cons( "?Perhaps you would like to be able to",
       cons( "?You want me to be able to" ,
       new LiImpl<String>())));

   canI
     = cons( "?Perhaps you don't want to",
       new LiImpl<String>("?Do you want to be able to" ,
       new LiImpl<String>()));


    youAre
     = cons( "?What makes you think I am",
       cons( "?Does it please you to believe I am",
       cons( "?Perhaps you would like to be",
       cons( "?Do you sometimes wish you were",
       new LiImpl<String>()))));

    iDont
     = cons( "?Don't you really",
       cons( "?Why don't you",
       cons( "?Do you wish to be able to",
       cons( "Does that trouble you?",
       new LiImpl<String>()))));

    iFeel	   
     = cons( "Tell me more about such feelings.",
       cons( "?Do you often feel",
       cons( "?Do you enjoy feeling",
       new LiImpl<String>())));

    iHave	   
    = cons( "?Do you often have",
 	  cons( "?How come that you have",
      cons( "?Are you sure you have",
      new LiImpl<String>())));
  
    whyDont  
     = cons( "?Do you really believe I don't",
       cons( ".Perhaps in good time I will",
       cons( "?Do you want me to",
       new LiImpl<String>())));

    whyCant
    =  cons( "?Do you think you should be able to",
       cons( "?Why can't you",
       new LiImpl<String>()));

    areYou
     = cons( "?Why are you interested in whether or not I am",
       cons( "?Would you prefer if I were not",
       cons( "?Perhaps in your fantasies I am",
       new LiImpl<String>())));

    iCant
     = cons( "?How do you know you can't",
       cons( "Have you tried?",
       cons( "?Perhaps you can now" ,
       new LiImpl<String>())));

    iAm	    
     = cons( "?Did you come to me because you are",
       cons( "?How long have you been",
       cons( "?Do you believe it is normal to be",
       cons( "?Do you enjoy being" ,
       new LiImpl<String>()))));

    you	     
     = cons( "We were discussing you --not me.",
       cons( "?Oh,",
       cons( "You're not really talking about me, are you?" ,
       new LiImpl<String>())));

    yes
     = cons( "You seem quite positive.",
       cons( "Are you Sure?",
       cons( "I see.",
       cons( "I understand." ,
       new LiImpl<String>()))));

    no
     = cons( "Are you saying no just to be negative?",
       cons( "You are being a bit negative.",
       cons( "Why not?",
       cons( "Are you sure?",
       cons( "Why no?" ,
       new LiImpl<String>())))));

    computer
     = cons( "Do computers worry you?",
       cons( "Are you talking about me in particular?",
       cons( "Are you frightened by machines?",
       cons( "Why do you mention computers?",
       cons( "What do you think machines have to do with your problems?",
       cons( "Don't you think computers can help people?",
       cons( "What is it about machines that worries you?" ,
       new LiImpl<String>())))))));

    problem
     = cons( "Is this really a poblem?",
       cons( "Don't you see any solution to this?",
       cons( "Is this your only problem?",
       cons( "Has this always been a problem?",
       new LiImpl<String>()))));

    iWant
     = cons( "?Why do you want",
       cons( "?What would it mean to you if you got",
       cons( "?Suppose you got",
       cons( "?What if you never got",
       cons( ".I sometimes also want" ,
       new LiImpl<String>())))));

    question
     = cons( "Why do you ask?",
       cons( "Does that question interest you?",
       cons( "What answer would please you the most?",
       cons( "What do you think?",
       cons( "Are such questions on your mind often?",
       cons( "What is it that you really want to know?",
       cons( "Have you asked anyone else?",
       cons( "Have you asked such questions before?",
       cons( "What else comes to mind when you ask that?" ,
       new LiImpl<String>())))))))));

    name
     = cons( "Names don't interest me.",
       cons( "I don't care about names --please go on." ,
       new LiImpl<String>()));

    because
     =  cons( "Is that the real reason?",
        cons( "Don't any other reasons come to mind?",
        cons( "Does that reason explain anything else?",
        cons( "What other reasons might there be?" ,
        new LiImpl<String>()))));

    sorry	
     = cons( "Please don't apologise!",
       cons( "Apologies are not necessary.",
       cons( "What feelings do you have when you apologise?",
       cons( "Don't be so defensive!" ,
       new LiImpl<String>()))));

    dream
     = cons( "What does that dream suggest to you?",
       cons( "Do you dream often?",
       cons( "What persons appear in your dreams?",
       cons( "Are you disturbed by your dreams?" ,
       new LiImpl<String>()))));

    hello
     = cons( "How do you...please state your problem." ,new LiImpl<String>());

    maybe
     = cons( "You don't seem quite certain.",
       cons( "Why the uncertain tone?",
       cons( "Can't you be more positive?",
       cons( "You aren't sure?",
       cons( "Don't you know?" ,
       new LiImpl<String>())))));

    your
     = cons( "?Why are you concerned about my",
       cons( "?What about your own" ,new LiImpl<String>()));

    always
     = cons( "Can you think of a specific example?",
       cons( "When?",
       cons( "What are you thinking of?",
       cons( "Really, always?" ,new LiImpl<String>()))));

    think
     = cons( "Do you really think so?",
       cons( "?But you are not sure you",
       cons( "?Do you doubt you" ,new LiImpl<String>())));

    alike
     = cons( "In what way?",
       cons( "What resemblence do you see?",
       cons( "What does the similarity suggest to you?",
       cons( "What other connections do you see?",
       cons( "Cound there really be some connection?",
       cons( "How?" ,new LiImpl<String>()))))));

    friend
     = cons( "Why do you bring up the topic of friends?",
       cons( "Do your friends worry you?",
       cons( "Do your friends pick on you?",
       cons( "Are you sure you have any friends?",
       cons( "Do you impose on your friends?",
       cons( "Perhaps your love for friends worries you." ,new LiImpl<String>()))))));

    respMsgs   
       = map(words("CAN YOU"),canYou,
         map(words("CAN I"),  canI,
         map(words("YOU ARE"),youAre,
         map(words("YOU'RE"),youAre,
         map(words("I DON'T"),iDont,
         map(words("I DON NOT"),iDont,
         map(words("I FEEL"), iFeel,
         map(words("I HAVE"), iHave,
         map(words("WHY DON'T YOU"),whyDont,
         map(words("WHY CAN'T I"),whyCant,
         map(words("ARE YOU"), areYou, 
         map(words("I CAN'T"),iCant,
         map(words("I CANNOT"),iCant,
         map(words("I AM"),iAm,
         map(words("I'M"), iAm,
         map(words("YOU"), you,
         map(words("YES"), yes,
         map(words("NO"), no,
         map(words("I HAVE A PROBLEM"),problem,
         map(words("I'VE A PROBLEM"),problem,
         map(words("PROBLEM"),problem,
         map(words("COMPUTER"),computer,
         map(words("COMPUTERS"),computer,
         map(words("I WANT"), iWant,
         map(words("WHAT"), question,
         map(words("HOW"),question,
         map(words("WHO"),question,
         map(words("WHERE"), question,
         map(words("WHEN"),question,
         map(words("WHY"), question,
         map(words("NAME"),name,
         map(words("BECAUSE"),because,
         map(words("CAUSE"), because,
         map(words("SORRY"), sorry,
         map(words("DREAM"), dream,
         map(words("DREAMS"),dream,
         map(words("HI"),hello,
         map(words("HELLO"), hello,
         map(words("MAYBE"),maybe,
         map(words("YOUR"),your,
         map(words("ALWAYS"),always,
         map(words("THINK"),think,
         map(words("ALIKE"),alike,
         map(words("FRIEND"),friend,
         map(words("FRIENDS"),friend,
       	 map((Li<String>)new LiImpl<String>(),nokeyMsgs, 
         new Map<Li<String>,Li<String>>()
         ))))))))))))))))))))))))))))))))))))))))))))));
    }
}
